Python LDAP Server Library
==========================

Python library that implements the socketserver.BaseRequestHandler interface
for LDAP. It provides stubs for all operations (BIND, SEARCH, ...). Overwrite
the stubs you need to provide actual functionality.

**Early prototype, API not stable yet, do not rely on it!**
